==> knox-1.2.0-src.zip: knox-1.2.0/gateway-server/src/main/java/org/apache/knox/gateway/services/metrics/impl/DefaultMetricsContext.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * <p>
 * http://www.apache.org/licenses/LICENSE-2.0
 * <p>
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.knox.gateway.services.metrics.impl;

import org.apache.knox.gateway.services.metrics.MetricsContext;
import org.apache.knox.gateway.services.metrics.MetricsService;

import java.util.HashMap;

public class DefaultMetricsContext implements MetricsContext {

  private MetricsService metricsService;

  private HashMap<String, Object> properties = new HashMap<>();

  public DefaultMetricsContext(MetricsService metricsService) {
    this.metricsService = metricsService;
  }

  @Override
  public MetricsService getMetricsService() {
    return metricsService;
  }

  @Override
  public void setProperty(String name, Object value) {
    properties.put(name, value);
  }

  @Override
  public Object getProperty(String name) {
    return properties.get(name);
  }
}

==> knox-2.1.0-src.zip: knox-2.1.0/gateway-server/src/main/java/org/apache/knox/gateway/services/metrics/impl/DefaultMetricsContext.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * <p>
 * http://www.apache.org/licenses/LICENSE-2.0
 * <p>
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.knox.gateway.services.metrics.impl;

import org.apache.knox.gateway.services.metrics.MetricsContext;
import org.apache.knox.gateway.services.metrics.MetricsService;

import java.util.HashMap;
import java.util.Map;

public class DefaultMetricsContext implements MetricsContext {

  private MetricsService metricsService;

  private Map<String, Object> properties = new HashMap<>();

  public DefaultMetricsContext(MetricsService metricsService) {
    this.metricsService = metricsService;
  }

  @Override
  public MetricsService getMetricsService() {
    return metricsService;
  }

  @Override
  public void setProperty(String name, Object value) {
    properties.put(name, value);
  }

  @Override
  public Object getProperty(String name) {
    return properties.get(name);
  }
}
